GlyphCaches

Struct GlyphCaches 

pub struct GlyphCaches {
    pub(crate) outline_cache: OutlineCache,
    pub(crate) hinting_cache: HintCache,
    pub(crate) underline_exclusions: Vec<(f64, f64)>,
    pub(crate) glyph_atlas: GlyphAtlas,
}
Caches used for glyph rendering.

Contains renderer-agnostic caches (outline paths, hinting instances) alongside the glyph atlas bitmap cache.

Fields

outline_cache: OutlineCache

Caches glyph outlines (paths) for reuse.

hinting_cache: HintCache

Caches hinting instances for reuse.

underline_exclusions: Vec<(f64, f64)>

Horizontal spans excluded from “ink-skipping” underlines. Cached to reuse one allocation.

glyph_atlas: GlyphAtlas

Caches rasterized glyph bitmaps in atlas pages.

Implementations

Source

impl GlyphCaches

pub fn clear(&mut self)

Clears the glyph caches.

pub fn maintain(&mut self, image_cache: &mut ImageCache)

Maintains the glyph caches by evicting unused cache entries.

The image_cache must be the same allocator passed to GlyphRunBuilder::build so that evicted entries are deallocated from the correct allocator.

Should be called once per scene rendering.